====================
django-generic-feeds
====================

A simple way for objects to subscribe to other objects for a "feed-like"
functionality in a Django project.


Installation
============

Run ``setup.py install`` or add to your Python path and include ``'feeds'``
in your ``INSTALLED_APPS`` setting.


Need Help?
==========

Email: rvause@gmail.com

Github: https://github.com/rvause/django-generic-feeds
